Index: /trunk/Eval/JET/makefile
===================================================================
--- /trunk/Eval/JET/makefile	(revision 2436)
+++ /trunk/Eval/JET/makefile	(revision 2437)
@@ -14,5 +14,5 @@
 # USERFLAGS := -I/.../myincludes 
 
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 
Index: /trunk/SophyaExt/CodeMinuit/MakeMinuit
===================================================================
--- /trunk/SophyaExt/CodeMinuit/MakeMinuit	(revision 2436)
+++ /trunk/SophyaExt/CodeMinuit/MakeMinuit	(revision 2437)
@@ -1,3 +1,3 @@
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 
Index: /trunk/SophyaExt/CodeMinuit/Makefile
===================================================================
--- /trunk/SophyaExt/CodeMinuit/Makefile	(revision 2436)
+++ /trunk/SophyaExt/CodeMinuit/Makefile	(revision 2437)
@@ -1,3 +1,3 @@
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 all:
Index: /trunk/SophyaExt/CodeMinuit/code/MakeMinuit
===================================================================
--- /trunk/SophyaExt/CodeMinuit/code/MakeMinuit	(revision 2436)
+++ /trunk/SophyaExt/CodeMinuit/code/MakeMinuit	(revision 2437)
@@ -1,3 +1,3 @@
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 
Index: /trunk/SophyaExt/JThreadsC++/Examples/Makefile
===================================================================
--- /trunk/SophyaExt/JThreadsC++/Examples/Makefile	(revision 2436)
+++ /trunk/SophyaExt/JThreadsC++/Examples/Makefile	(revision 2437)
@@ -4,6 +4,6 @@
 
 CXX := g++
-ifdef EROSCXX
-  CXX := $(EROSCXX)
+ifdef SOPHYACXX
+  CXX := $(SOPHYACXX)
 endif
 
Index: /trunk/SophyaExt/JThreadsC++/JTCSrc/Makefile
===================================================================
--- /trunk/SophyaExt/JThreadsC++/JTCSrc/Makefile	(revision 2436)
+++ /trunk/SophyaExt/JThreadsC++/JTCSrc/Makefile	(revision 2437)
@@ -4,6 +4,6 @@
 
 CXX := g++
-ifdef EROSCXX
-  CXX := $(EROSCXX)
+ifdef SOPHYACXX
+  CXX := $(SOPHYACXX)
 endif
 
Index: /trunk/SophyaExt/JThreadsC++/README
===================================================================
--- /trunk/SophyaExt/JThreadsC++/README	(revision 2436)
+++ /trunk/SophyaExt/JThreadsC++/README	(revision 2437)
@@ -28,5 +28,5 @@
 
 1) Select the compiler through the environment variable 
-EROSCXX
+SOPHYACXX
 2) Build the libray (make in JTCSrc)
 3) Define the path for installation through the 
@@ -35,5 +35,5 @@
 5) Try to build and test the example programs
 (make in Examples/) - The LD_LIBRARY_PATH should
-contain $JTCBASEREP/`uname`-$EROSCXX/ShLibs
+contain $JTCBASEREP/`uname`-$SOPHYACXX/ShLibs
 6) The use of GNU make is mandatory
 
@@ -42,5 +42,5 @@
 using c-shell commands. (uname = OSF1)
 
-Cmd> setenv EROSCXX cxx
+Cmd> setenv SOPHYACXX cxx
 Cmd> setenv JTCBASEREP /usr/local/
 Cmd> cd JTCSrc
Index: /trunk/SophyaExt/XAstroPack/Maketest
===================================================================
--- /trunk/SophyaExt/XAstroPack/Maketest	(revision 2436)
+++ /trunk/SophyaExt/XAstroPack/Maketest	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME :=  CmvTests
 MODULEDECCXXFLAGS := -msg_quiet
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 LIBNEED := -L$(SLB) -lsophya -L$(LIB) -lFitsIOServer -L$(EXTLIBPATH) -lcfitsio
Index: /trunk/SophyaExt/XephemAstroLib/Makefile
===================================================================
--- /trunk/SophyaExt/XephemAstroLib/Makefile	(revision 2436)
+++ /trunk/SophyaExt/XephemAstroLib/Makefile	(revision 2437)
@@ -1,3 +1,3 @@
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 all: libxastro.a
Index: /trunk/SophyaLib/Manual/piapp.tex
===================================================================
--- /trunk/SophyaLib/Manual/piapp.tex	(revision 2436)
+++ /trunk/SophyaLib/Manual/piapp.tex	(revision 2437)
@@ -85,6 +85,6 @@
 a copy of the on-line help (accessible through the menu {\tt File/Help}). 
 Once the SOPHYA/piapp (or PEIDA++/piapp) environment 
-\footnote{ The environment variables {\tt DPCBASEREP} (or {\tt EROSBASEREP}),
-{\tt EROSCXX} (compiler selector), the shared library path 
+\footnote{ The environment variables {\tt SOPHYABASEREP} (or {\tt EROSBASEREP}),
+{\tt SOPHYACXX} (compiler selector), the shared library path 
 {\tt LD\_LIBRARY\_PATH} and the executable search path {\tt PATH} must
 be defined}
Index: /trunk/SophyaLib/Manual/sophya.tex
===================================================================
--- /trunk/SophyaLib/Manual/sophya.tex	(revision 2436)
+++ /trunk/SophyaLib/Manual/sophya.tex	(revision 2437)
@@ -174,8 +174,8 @@
 
 \subsection{Environment variables}
-Two environment variables {\bf DPCBASEREP} and {\bf EROSCXX} are used 
+Two environment variables {\bf SOPHYABASEREP} and {\bf SOPHYACXX} are used 
 to define the path where the Sophya libraries and executable are installed.
-{\bf DPCBASEREP} defines the base directory path and {\bf EROSCXX} the 
-name of the C++ compiler. The complete path is built using {\bf DPCBASEREP},
+{\bf SOPHYABASEREP} defines the base directory path and {\bf SOPHYACXX} the 
+name of the C++ compiler. The complete path is built using {\bf SOPHYABASEREP},
 the operating system name (as obtained by the {\tt uname} command), and
 the compiler name. In the example below, we show the complete path 
@@ -183,13 +183,13 @@
 
 \begin{itemize}
-\item \$DPCBASEREP/Include : Include (.h) files
-\item \$DPCBASEREP/Linux-g++/Libs : Path for the archive libraries (.a)
-\item \$DPCBASEREP/Linux-g++/ShLibs : Shared library path (.so)
-\item \$DPCBASEREP/Linux-g++/Exec : Executable file path
+\item \$SOPHYABASEREP/Include : Include (.h) files
+\item \$SOPHYABASEREP/Linux-g++/Libs : Path for the archive libraries (.a)
+\item \$SOPHYABASEREP/Linux-g++/ShLibs : Shared library path (.so)
+\item \$SOPHYABASEREP/Linux-g++/Exec : Executable file path
 \end{itemize}
 
 In order to use the shared libraries, the {\bf LD\_LIBRARY\_PATH} variable
 should contain the Sophya shared library path 
-({\tt \$DPCBASEREP/Linux-g++/ShLibs } when using g++ compiler on Linux)
+({\tt \$SOPHYABASEREP/Linux-g++/ShLibs } when using g++ compiler on Linux)
 
 For modules using external libraries, the {\bf EXTLIBDIR} 
@@ -203,10 +203,10 @@
 
 \subsection{User makefiles}
-The file {\tt \$DPCBASEREP/Include/MakefileUser.h} defines the compilation 
+The file {\tt \$SOPHYABASEREP/Include/MakefileUser.h} defines the compilation 
 flags and the list of Sophya libraries. It should be included in the 
 user's makefile. The default compilation rules assumes that the object (.o) 
 and executable files would be put in the following directories: \\
-{\tt \$HOME/`uname`-\$EROSCXX/Objs} \\ 
-{\tt \$HOME/`uname`-\$EROSCXX/Exec}.
+{\tt \$HOME/`uname`-\$SOPHYACXX/Objs} \\ 
+{\tt \$HOME/`uname`-\$SOPHYACXX/Exec}.
 In the case of a {\tt Linux} system and using {\tt g++} as the C++ compiler, 
 these two directories would be translated to \\
@@ -1517,5 +1517,5 @@
 The build procedure expects to find the include files and the libraries in: \\
 {\tt \$EXTLIBDIR/Include/FitsIO } \\
-{\tt \$EXTLIBDIR/`uname`-\$EROSCXX/Libs} \\
+{\tt \$EXTLIBDIR/`uname`-\$SOPHYACXX/Libs} \\
 The complete directory tree content for the various external libraries used 
 by this version of SOPHYA is listed below:
@@ -1544,5 +1544,5 @@
 grouped in ({\tt libPI.so}).
 
-The environment variables {\bf DPCDEVREP}, {\bf EXTLIBDIR} and {\bf EROSCXX}
+The environment variables {\bf SOPHYADEVREP}, {\bf EXTLIBDIR} and {\bf SOPHYACXX}
 must be defined in order to install the Sophya package.
 In the example below, we assume that we want to install Sophya from a 
@@ -1559,8 +1559,8 @@
 \begin{verbatim}
 # We select our C++ compiler
-csh> setenv EROSCXX g++
+csh> setenv SOPHYACXX g++
 # Setup the build directory
 csh> mkdir /usr/local/Sophya/
-csh> setenv DPCDEVREP /usr/local/Sophya/
+csh> setenv SOPHYADEVREP /usr/local/Sophya/
 csh> setenv EXTLIBDIR /usr/local/ExtLibs/
 # Use the top level makefile in Mgr/ 
@@ -1620,9 +1620,9 @@
 for the different compilers and systems. (to be included in makefiles)
 \item {\bf crerep\_sophya} c-shell script for creating the directory tree
-under {\tt \$DPCBASEREP} and {\tt \$DPCDEVREP}
+under {\tt \$SOPHYABASEREP} and {\tt \$SOPHYADEVREP}
 \item {\bf install\_sophya} c-shell script for installing the Sophya package.
-Usually from {\tt \$DPCDEVREP} to {\tt \$DPCBASEREP}
+Usually from {\tt \$SOPHYADEVREP} to {\tt \$SOPHYABASEREP}
 \item {\bf mkmflien} c-shell script for making symbolic links or copying
-include files to {\tt \$DPCDEVREP/Include} or {\tt \$DPCBASEREP/Include}
+include files to {\tt \$SOPHYADEVREP/Include} or {\tt \$SOPHYABASEREP/Include}
 \item {\bf mkmf} c-shell script for generating module makefiles and the 
 top level makefile (named GNUmakefile)
Index: /trunk/SophyaLib/Mgr/Makefile
===================================================================
--- /trunk/SophyaLib/Mgr/Makefile	(revision 2436)
+++ /trunk/SophyaLib/Mgr/Makefile	(revision 2437)
@@ -21,19 +21,19 @@
 #--- Create directory and copy includes for install
 depend:
-ifdef DPCDEVREP
-ifdef EROSCXX
+ifdef SOPHYADEVREP
+ifdef SOPHYACXX
 	@echo "Sophya will be installed under:"
-	@echo "  $(DPCDEVREP)/Include" 
-	@echo "  $(DPCDEVREP)/`uname`-$(EROSCXX)" 
+	@echo "  $(SOPHYADEVREP)/Include" 
+	@echo "  $(SOPHYADEVREP)/`uname`-$(SOPHYACXX)" 
 	if [ -d Mgr ] ; then cd Mgr; \
-	./crerep_sophya $(DPCDEVREP) `uname`-$(EROSCXX); \
+	./crerep_sophya $(SOPHYADEVREP) `uname`-$(SOPHYACXX); \
 	./makefileuser.csh; \
 	./mkmflien -copy ; \
 	fi
 else
-	@echo "Variable EROSCXX must be define with setenv"
+	@echo "Variable SOPHYACXX must be define with setenv"
 endif
 else
-	@echo "Variable DPCDEVREP must be define with setenv"
+	@echo "Variable SOPHYADEVREP must be define with setenv"
 endif
 #--------------------------------------------------------------------
Index: /trunk/SophyaLib/Mgr/Makefile.slb
===================================================================
--- /trunk/SophyaLib/Mgr/Makefile.slb	(revision 2436)
+++ /trunk/SophyaLib/Mgr/Makefile.slb	(revision 2437)
@@ -47,5 +47,5 @@
 USECXX4SO := Y
 # On utilise le compilo g++ pour la fabrication des shared libs
-ifeq ($(EROSCXX), g++)
+ifeq ($(SOPHYACXX), g++)
   override USECXX4SO := Y
   override CMDSHLCXX := $(LINK.cc) -shared
@@ -54,5 +54,5 @@
 
 # On utilise le compilo KCC pour la fabrication des shared libs
-ifeq ($(EROSCXX), KCC)
+ifeq ($(SOPHYACXX), KCC)
   override USECXX4SO := Y
   override CMDSHLCXX := $(LINK.cc)
@@ -60,5 +60,5 @@
 
 # On utilise le compilo aCC (HP) pour la fabrication des shared libs
-ifeq ($(EROSCXX), aCC)
+ifeq ($(SOPHYACXX), aCC)
   override USECXX4SO := Y
   override CMDSHLCXX := $(LINK.cc) -b
@@ -93,5 +93,5 @@
   override FGSHLN := --no-whole-archiv
   override CMDSHLCXX := $(LINK.cc) -shared 
-  ifeq ($(EROSCXX), KCC)
+  ifeq ($(SOPHYACXX), KCC)
     override CMDSHLCXX := $(LINK.cc)
   endif
@@ -120,5 +120,5 @@
   override FGSHLN := -notall
   override TILSHL := 
-  ifeq ($(EROSCXX), CC)
+  ifeq ($(SOPHYACXX), CC)
     override CMDSHLCXX := CC -shared 
   endif
Index: /trunk/SophyaLib/Mgr/README
===================================================================
--- /trunk/SophyaLib/Mgr/README	(revision 2436)
+++ /trunk/SophyaLib/Mgr/README	(revision 2437)
@@ -58,22 +58,22 @@
 MacOSX/Darwin 10.1           c++/gcc 2.95    (shared-library only)
 
-The environment variables  DPCDEVREP EXTLIBDIR EROSCXX must be defined
+The environment variables  SOPHYADEVREP EXTLIBDIR SOPHYACXX must be defined
 for building and installing the libraries.
 
-$EROSCXX is the name of C++ compiler being used.
-$DPCDEVREP is the path to where the libraries and executables will be put.
-$DPCDEVREP/Include : header files
+$SOPHYACXX is the name of C++ compiler being used.
+$SOPHYADEVREP is the path to where the libraries and executables will be put.
+$SOPHYADEVREP/Include : header files
 The libraries and binaries will be put in subdirectories containing 
-the operating system name and the compiler name: `uname`-$EROSCXX
+the operating system name and the compiler name: `uname`-$SOPHYACXX
 For example, on a Linux system, using the GNU compiler:
 
-$DPCDEVREP/Linux-g++/Libs     archive librarires
-$DPCDEVREP/Linux-g++/ShLibs   shared libraries
-$DPCDEVREP/Linux-g++/Exec     binaries
+$SOPHYADEVREP/Linux-g++/Libs     archive librarires
+$SOPHYADEVREP/Linux-g++/ShLibs   shared libraries
+$SOPHYADEVREP/Linux-g++/Exec     binaries
 
 The build procedure expects to find the include files and the libraries 
 for cfitsio in :
 $EXTLIBDIR/Include/FitsIO 
-$EXTLIBDIR/`uname`-$EROSCXX/Libs
+$EXTLIBDIR/`uname`-$SOPHYACXX/Libs
 This would translate to Linux-g++ on a Linux system, using g++.
 $EXTLIBDIR/Linux-g++/Libs
@@ -83,9 +83,9 @@
 
 # We select our C++ compiler
-csh> setenv EROSCXX g++
+csh> setenv SOPHYACXX g++
 # Setup the build directory
 csh> mkdir /usr/local/Sophya/
-csh> setenv DPCDEVREP  /usr/local/Sophya/
-csh> setenv DPCBASEREP /usr/local/Sophya/
+csh> setenv SOPHYADEVREP  /usr/local/Sophya/
+csh> setenv SOPHYABASEREP /usr/local/Sophya/
 csh> setenv EXTLIBDIR  /usr/local/ExtLibs/
 
@@ -174,10 +174,10 @@
   Usage: crerep_sophya <nom des repertoires> [nom_machine-compilateur]
   Example :
-  Cmd> crerep_sophya $DPCDEVREP OSF1-cxx 
+  Cmd> crerep_sophya $SOPHYADEVREP OSF1-cxx 
   Cmd> crerep_sophya ~/Work/ Linux-g++
 
 * install_sophya
-  Install SOPHYA libraries/include files from dev directory ($DPCDEVREP)
-  to the install ($DPCBASEREP) directory
+  Install SOPHYA libraries/include files from dev directory ($SOPHYADEVREP)
+  to the install ($SOPHYABASEREP) directory
   Copy files Include/*.h Libs/*.a ShLibs/*.so Exec/*
 
@@ -192,5 +192,5 @@
 
   Steps :
-  - mkmflien : Creates symbolic links for all header files in $DPCDEVREP/Include
+  - mkmflien : Creates symbolic links for all header files in $SOPHYADEVREP/Include
 
   - mkmflib : Creation of a GNUmakefile in each library module
Index: /trunk/SophyaLib/Mgr/cleantstprg.csh
===================================================================
--- /trunk/SophyaLib/Mgr/cleantstprg.csh	(revision 2436)
+++ /trunk/SophyaLib/Mgr/cleantstprg.csh	(revision 2437)
@@ -1,5 +1,5 @@
 #!/bin/csh
-set OBJREP = ${DPCDEVREP}/`uname`-$EROSCXX/Objs/
-set EXEREP = ${DPCDEVREP}/`uname`-$EROSCXX/Exec/
+set OBJREP = ${SOPHYADEVREP}/`uname`-$SOPHYACXX/Objs/
+set EXEREP = ${SOPHYADEVREP}/`uname`-$SOPHYACXX/Exec/
 echo ' ---> cleantstprg.csh: Removing Objs/$f.o , Exec/$f '
 foreach f (*.cc)
Index: /trunk/SophyaLib/Mgr/crerep_sophya
===================================================================
--- /trunk/SophyaLib/Mgr/crerep_sophya	(revision 2436)
+++ /trunk/SophyaLib/Mgr/crerep_sophya	(revision 2437)
@@ -6,6 +6,6 @@
   echo " - possibilites nom_machine-compilateur"
   echo "    [AIX-xlC AIX-g++ HP-UX-aCC HP-UX-g++ OSF1-cxx OSF1-g++ Linux-g++ ...]"
-  if($?EROSCXX) then
-    echo "    defaut: `uname`-$EROSCXX"
+  if($?SOPHYACXX) then
+    echo "    defaut: `uname`-$SOPHYACXX"
   else
     echo "    pas de defaut donnez explicitement nom_machine-compilateur"
@@ -26,10 +26,10 @@
   set diru = $1
   echo "machine-compilateur: ${diru}"
-else if ($?EROSCXX) then
-  echo uname=`uname` EROSCXX = $EROSCXX
-  set diru = `uname`-$EROSCXX
+else if ($?SOPHYACXX) then
+  echo uname=`uname` SOPHYACXX = $SOPHYACXX
+  set diru = `uname`-$SOPHYACXX
   echo "AUTOMATIQUE machine-compilateur: ${diru}"
 else
-  echo "precisez nom_machine-compilateur ou EROSCXX"
+  echo "precisez nom_machine-compilateur ou SOPHYACXX"
   exit -1
 endif
Index: /trunk/SophyaLib/Mgr/install_sophya
===================================================================
--- /trunk/SophyaLib/Mgr/install_sophya	(revision 2436)
+++ /trunk/SophyaLib/Mgr/install_sophya	(revision 2437)
@@ -6,11 +6,11 @@
   echo "install_sophya <-s repertoire source> <-d repertoire destination>"
   echo "              [-m nom_machine-compilateur]"
-  if($?DPCDEVREP) then
-    echo " - defaut repertoire source: $DPCDEVREP"
+  if($?SOPHYADEVREP) then
+    echo " - defaut repertoire source: $SOPHYADEVREP"
   else
     echo "   pas de defaut donnez explicitement le repertoire source"
   endif
-  if($?DPCBASEREP) then
-    echo " - defaut repertoire destination: $DPCBASEREP"
+  if($?SOPHYABASEREP) then
+    echo " - defaut repertoire destination: $SOPHYABASEREP"
   else
     echo "   pas de defaut donnez explicitement le repertoire destination"
@@ -18,6 +18,6 @@
   echo " - possibilites nom_machine-compilateur"
   echo "    [AIX-xlC AIX-g++ HP-UX-aCC HP-UX-g++ OSF1-cxx OSF1-g++  Linux-g++ ...]"
-  if($?EROSCXX) then
-    echo "    defaut: `uname`-$EROSCXX"
+  if($?SOPHYACXX) then
+    echo "    defaut: `uname`-$SOPHYACXX"
   else
     echo "    pas de defaut donnez explicitement nom_machine-compilateur"
@@ -44,15 +44,15 @@
 end
 
-if( ! $?srcdir && $?DPCDEVREP ) then
-  echo "defaut srcdir set to DPCDEVREP"
-  set srcdir = $DPCDEVREP
+if( ! $?srcdir && $?SOPHYADEVREP ) then
+  echo "defaut srcdir set to SOPHYADEVREP"
+  set srcdir = $SOPHYADEVREP
 endif
-if( ! $?dstdir && $?DPCBASEREP ) then
-  echo "defaut dstdir set to DPCBASEREP"
-  set dstdir = $DPCBASEREP
+if( ! $?dstdir && $?SOPHYABASEREP ) then
+  echo "defaut dstdir set to SOPHYABASEREP"
+  set dstdir = $SOPHYABASEREP
 endif
-if( ! $?macomp && $?EROSCXX ) then
-  echo "defaut macomp set to uname-EROSCXX"
-  set macomp = `uname`-$EROSCXX
+if( ! $?macomp && $?SOPHYACXX ) then
+  echo "defaut macomp set to uname-SOPHYACXX"
+  set macomp = `uname`-$SOPHYACXX
 endif
 
Index: /trunk/SophyaLib/Mgr/makefile.darwin
===================================================================
--- /trunk/SophyaLib/Mgr/makefile.darwin	(revision 2436)
+++ /trunk/SophyaLib/Mgr/makefile.darwin	(revision 2437)
@@ -21,19 +21,19 @@
 #--- Create directory and copy includes for install
 depend:
-ifdef DPCDEVREP
-ifdef EROSCXX
+ifdef SOPHYADEVREP
+ifdef SOPHYACXX
 	@echo "Sophya will be installed under:"
-	@echo "  $(DPCDEVREP)/Include" 
-	@echo "  $(DPCDEVREP)/`uname`-$(EROSCXX)" 
+	@echo "  $(SOPHYADEVREP)/Include" 
+	@echo "  $(SOPHYADEVREP)/`uname`-$(SOPHYACXX)" 
 	if [ -d Mgr ] ; then cd Mgr; \
-	./crerep_sophya $(DPCDEVREP) `uname`-$(EROSCXX); \
+	./crerep_sophya $(SOPHYADEVREP) `uname`-$(SOPHYACXX); \
 	./makefileuser.csh; \
 	./mkmflien -copy ; \
 	fi
 else
-	@echo "Variable EROSCXX must be define with setenv"
+	@echo "Variable SOPHYACXX must be define with setenv"
 endif
 else
-	@echo "Variable DPCDEVREP must be define with setenv"
+	@echo "Variable SOPHYADEVREP must be define with setenv"
 endif
 #--------------------------------------------------------------------
Index: /trunk/SophyaLib/Mgr/makefileuser.awk
===================================================================
--- /trunk/SophyaLib/Mgr/makefileuser.awk	(revision 2436)
+++ /trunk/SophyaLib/Mgr/makefileuser.awk	(revision 2437)
@@ -1,5 +1,5 @@
 BEGIN {change=0;}
-/^PP  := \$\{DPCDEVREP\}\/\$\{MACHDIR\}\// {
-  print "PP  := \$\{DPCBASEREP\}\/\$\{MACHDIR\}\/";
+/^PP  := \$\{SOPHYADEVREP\}\/\$\{MACHDIR\}\// {
+  print "PP  := \$\{SOPHYABASEREP\}\/\$\{MACHDIR\}\/";
   print "PPH := \$\{HOME\}\/\$\{MACHDIR\}\/";
   change=1;
@@ -13,6 +13,6 @@
   change=1;
 }
-/^INC := \$\{DPCDEVREP\}\/Include\// {
-  print "INC := \$\{DPCBASEREP\}\/Include\/";
+/^INC := \$\{SOPHYADEVREP\}\/Include\// {
+  print "INC := \$\{SOPHYABASEREP\}\/Include\/";
   change=1;
 }
Index: /trunk/SophyaLib/Mgr/mkmf
===================================================================
--- /trunk/SophyaLib/Mgr/mkmf	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkmf	(revision 2437)
@@ -1,4 +1,4 @@
 #!/bin/csh 
-# $Id: mkmf,v 1.18 2003-08-28 14:26:09 cmv Exp $
+# $Id: mkmf,v 1.19 2003-09-17 12:19:26 cmv Exp $
 
 #  Pour debugger 
@@ -98,19 +98,19 @@
 echo '#--- Create directory and copy includes for install' >> GNUmakefile
 echo 'depend:' >> GNUmakefile
-echo 'ifdef DPCDEVREP' >> GNUmakefile
-echo 'ifdef EROSCXX' >> GNUmakefile
+echo 'ifdef SOPHYADEVREP' >> GNUmakefile
+echo 'ifdef SOPHYACXX' >> GNUmakefile
 echo '	@echo "Sophya will be installed under:"' >> GNUmakefile
-echo '	@echo "  $(DPCDEVREP)/Include" ' >> GNUmakefile
-echo '	@echo "  $(DPCDEVREP)/`uname`-$(EROSCXX)" ' >> GNUmakefile
+echo '	@echo "  $(SOPHYADEVREP)/Include" ' >> GNUmakefile
+echo '	@echo "  $(SOPHYADEVREP)/`uname`-$(SOPHYACXX)" ' >> GNUmakefile
 echo '	if [ -d Mgr ] ; then cd Mgr; \' >> GNUmakefile
-echo '	./crerep_sophya $(DPCDEVREP) `uname`-$(EROSCXX); \' >> GNUmakefile
+echo '	./crerep_sophya $(SOPHYADEVREP) `uname`-$(SOPHYACXX); \' >> GNUmakefile
 echo '	./makefileuser.csh; \' >> GNUmakefile
 echo '	./mkmflien -copy ; \' >> GNUmakefile
 echo '	fi' >> GNUmakefile
 echo 'else' >> GNUmakefile
-echo '	@echo "Variable EROSCXX must be define with setenv"' >> GNUmakefile
+echo '	@echo "Variable SOPHYACXX must be define with setenv"' >> GNUmakefile
 echo 'endif' >> GNUmakefile
 echo 'else' >> GNUmakefile
-echo '	@echo "Variable DPCDEVREP must be define with setenv"' >> GNUmakefile
+echo '	@echo "Variable SOPHYADEVREP must be define with setenv"' >> GNUmakefile
 echo 'endif' >> GNUmakefile
 echo '#--------------------------------------------------------------------' >> GNUmakefile
Index: /trunk/SophyaLib/Mgr/mkmfPI
===================================================================
--- /trunk/SophyaLib/Mgr/mkmfPI	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkmfPI	(revision 2437)
@@ -1,4 +1,4 @@
 #!/bin/csh
-# $Id: mkmfPI,v 1.9 2002-05-14 15:14:47 ansari Exp $
+# $Id: mkmfPI,v 1.10 2003-09-17 12:19:26 cmv Exp $
 
 set makefname = 'GNUmakefile'
@@ -72,5 +72,5 @@
 echo " " >> $makefname
 
-set inc = $DPCDEVREP/Include
+set inc = $SOPHYADEVREP/Include
 set incext = $EXTLIBDIR/Include
 set nomsys = `uname`
Index: /trunk/SophyaLib/Mgr/mkmflib
===================================================================
--- /trunk/SophyaLib/Mgr/mkmflib	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkmflib	(revision 2437)
@@ -1,4 +1,4 @@
 #!/bin/csh
-# $Id: mkmflib,v 1.11 2002-05-14 15:14:47 ansari Exp $
+# $Id: mkmflib,v 1.12 2003-09-17 12:19:26 cmv Exp $
 
 cd ../$1
@@ -68,5 +68,5 @@
 echo " " >> GNUmakefile
 
-set inc = $DPCDEVREP/Include
+set inc = $SOPHYADEVREP/Include
 # set incxx = $inc/CxxInc
 set incext = $EXTLIBDIR/Include
Index: /trunk/SophyaLib/Mgr/mkmflib_save
===================================================================
--- /trunk/SophyaLib/Mgr/mkmflib_save	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkmflib_save	(revision 2437)
@@ -1,4 +1,4 @@
 #!/bin/csh
-# $Id: mkmflib_save,v 1.2 1999-10-25 16:24:49 ansari Exp $
+# $Id: mkmflib_save,v 1.3 2003-09-17 12:19:26 cmv Exp $
 
 cd ../$1
@@ -44,5 +44,5 @@
 echo " " >> GNUmakefile
 
-set inc = $DPCDEVREP/Include
+set inc = $SOPHYADEVREP/Include
 set incxx = $inc/CxxInc
 
Index: /trunk/SophyaLib/Mgr/mkmflien
===================================================================
--- /trunk/SophyaLib/Mgr/mkmflien	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkmflien	(revision 2437)
@@ -1,4 +1,4 @@
 #!/bin/csh
-# $Id: mkmflien,v 1.12 2001-12-19 18:34:11 ansari Exp $
+# $Id: mkmflien,v 1.13 2003-09-17 12:19:26 cmv Exp $
 
 # WARNING : mkmflien has to be runned FROM Mgr/
@@ -7,5 +7,5 @@
 #  -clean : after copy/link file are deleted if not existing (empty link)
 #  dir_dest : link/copy to dir_dest/
-#             default : $DPCDEVREP/Include
+#             default : $SOPHYADEVREP/Include
 
 #######################
@@ -15,6 +15,6 @@
 set cpln = "ln -sf"
 unset clln
-if( $?DPCDEVREP ) then
-  set dst = $DPCDEVREP/Include
+if( $?SOPHYADEVREP ) then
+  set dst = $SOPHYADEVREP/Include
 endif
 
@@ -31,5 +31,5 @@
 
 if( ! $?dst ) then
-  echo "Variable DPCDEVREP must be set"
+  echo "Variable SOPHYADEVREP must be set"
   echo "OR you must give a directory for linking/copying"
   exit -1
Index: /trunk/SophyaLib/Mgr/mkmfprog
===================================================================
--- /trunk/SophyaLib/Mgr/mkmfprog	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkmfprog	(revision 2437)
@@ -1,4 +1,4 @@
 #!/bin/csh 
-# $Id: mkmfprog,v 1.4 2000-04-13 15:56:03 ansari Exp $
+# $Id: mkmfprog,v 1.5 2003-09-17 12:19:26 cmv Exp $
 
 # $1 : nom du repertoire
@@ -78,5 +78,5 @@
 #end
 
-set inc = $DPCDEVREP/Include
+set inc = $SOPHYADEVREP/Include
 set incext = $EXTLIBDIR/Include
 set nomsys = `uname`
Index: /trunk/SophyaLib/Mgr/mkslbsgi.csh
===================================================================
--- /trunk/SophyaLib/Mgr/mkslbsgi.csh	(revision 2436)
+++ /trunk/SophyaLib/Mgr/mkslbsgi.csh	(revision 2437)
@@ -18,7 +18,7 @@
 set XPILIBS = "$LIBXPIPATH $LIBXPILIST"
 
-set LIB = $DPCDEVREP/IRIX64-CC/Libs/
-set SLB = $DPCDEVREP/IRIX64-CC/ShLibs/
-set OBJ = $DPCDEVREP/IRIX64-CC/Objs/
+set LIB = $SOPHYADEVREP/IRIX64-CC/Libs/
+set SLB = $SOPHYADEVREP/IRIX64-CC/ShLibs/
+set OBJ = $SOPHYADEVREP/IRIX64-CC/Objs/
 
 set EXTLIBPL = -L${EXTLIBDIR}/IRIX64-CC/Libs/
Index: /trunk/SophyaLib/Mgr/sgienv.csh
===================================================================
--- /trunk/SophyaLib/Mgr/sgienv.csh	(revision 2436)
+++ /trunk/SophyaLib/Mgr/sgienv.csh	(revision 2437)
@@ -24,22 +24,22 @@
 echo ' en.csh : setting environment variables for SOPHYA on SGI'
 
-setenv EROSCXX CC
+setenv SOPHYACXX CC
 if ($sgi64 == 'Y')  then
   echo ' SGI-64 bits architecture selected ... ' 
-  setenv DPCBASEREP /usr/local/Sophya64/$sversion
+  setenv SOPHYABASEREP /usr/local/Sophya64/$sversion
   setenv EXTLIBDIR /usr/local/Sophya64/ExtLibs
   setenv SOPHYA_SGI64 1
-  setenv LD_LIBRARY64_PATH .:${LD_LIBRARY64_PATH}:${DPCBASEREP}/IRIX64-CC/ShLibs
+  setenv LD_LIBRARY64_PATH .:${LD_LIBRARY64_PATH}:${SOPHYABASEREP}/IRIX64-CC/ShLibs
 else
-  setenv DPCBASEREP /usr/local/Sophya/$sversion
+  setenv SOPHYABASEREP /usr/local/Sophya/$sversion
   setenv EXTLIBDIR /usr/local/Sophya/ExtLibs
   unsetenv SOPHYA_SGI64
-  setenv LD_LIBRARYN32_PATH .:${LD_LIBRARYN32_PATH}:${DPCBASEREP}/IRIX64-CC/ShLibs
+  setenv LD_LIBRARYN32_PATH .:${LD_LIBRARYN32_PATH}:${SOPHYABASEREP}/IRIX64-CC/ShLibs
 endif
 
-set path = ($path $DPCBASEREP/IRIX64-CC/Exec)
+set path = ($path $SOPHYABASEREP/IRIX64-CC/Exec)
 
-echo ' EROSCXX= ' $EROSCXX
-echo ' DPCBASEREP= ' $DPCBASEREP
+echo ' SOPHYACXX= ' $SOPHYACXX
+echo ' SOPHYABASEREP= ' $SOPHYABASEREP
 echo ' EXTLIBDIR= ' $EXTLIBDIR
 echo ' LD_LIBRARYN32_PATH= ' $LD_LIBRARYN32_PATH 
Index: /trunk/SophyaLib/Mgr/tar_for_web.csh
===================================================================
--- /trunk/SophyaLib/Mgr/tar_for_web.csh	(revision 2436)
+++ /trunk/SophyaLib/Mgr/tar_for_web.csh	(revision 2437)
@@ -33,19 +33,19 @@
   endif
 end
-if( ! $?DPCBASEREP ) then
-  echo Precisez DPCBASEREP
+if( ! $?SOPHYABASEREP ) then
+  echo Precisez SOPHYABASEREP
   exit -1
 endif
-if( ! -e $DPCBASEREP/Include ) then
-  echo Pas de repertoire $DPCBASEREP/Include
+if( ! -e $SOPHYABASEREP/Include ) then
+  echo Pas de repertoire $SOPHYABASEREP/Include
   exit -1
 endif
-if( ! -e $DPCBASEREP/${OSCC} ) then
-  echo Pas de repertoire $DPCBASEREP/${OSCC}
+if( ! -e $SOPHYABASEREP/${OSCC} ) then
+  echo Pas de repertoire $SOPHYABASEREP/${OSCC}
   exit -1
 endif
 foreach d ( Libs ShLibs Exec )
-  if( ! -d $DPCBASEREP/${OSCC}/$d ) then
-    echo repertoire $DPCBASEREP/${OSCC}/$d inexistant
+  if( ! -d $SOPHYABASEREP/${OSCC}/$d ) then
+    echo repertoire $SOPHYABASEREP/${OSCC}/$d inexistant
     exit -1
   endif
@@ -71,5 +71,5 @@
 set SYS = `echo $OSCC | awk -F"-" '{print $1}'`
 echo "SOURCE        = " `pwd`
-echo "DPCBASEREP    = " $DPCBASEREP
+echo "SOPHYABASEREP    = " $SOPHYABASEREP
 echo "EXTLIBDIR     = " $EXTLIBDIR
 echo "Version       = " $VS
@@ -124,8 +124,8 @@
 ##################################################
 echo '>>>>>>>>' Librairies et executables de Sophya
-pushd $DPCBASEREP > /dev/null
+pushd $SOPHYABASEREP > /dev/null
 tar -chf - Include |(cd $tmp/${VS}/.; tar -xf -)
 popd > /dev/null
-pushd $DPCBASEREP/${OSCC} > /dev/null
+pushd $SOPHYABASEREP/${OSCC} > /dev/null
 tar -chf - Libs   |(cd $tmp/${VS}/.; tar -xf -)
 tar -chf - ShLibs |(cd $tmp/${VS}/.; tar -xf -)
Index: /trunk/SophyaLib/SysTools/cxxcmplnk.cc
===================================================================
--- /trunk/SophyaLib/SysTools/cxxcmplnk.cc	(revision 2436)
+++ /trunk/SophyaLib/SysTools/cxxcmplnk.cc	(revision 2437)
@@ -110,5 +110,5 @@
   string dpcbase;
   char* varenv=NULL;
-  varenv=getenv("DPCBASEREP");
+  varenv=getenv("SOPHYABASEREP");
   if (varenv) {
     dpcbase = varenv; 
Index: /trunk/SophyaPI/DemoPIApp/Makefile
===================================================================
--- /trunk/SophyaPI/DemoPIApp/Makefile	(revision 2436)
+++ /trunk/SophyaPI/DemoPIApp/Makefile	(revision 2437)
@@ -1,4 +1,4 @@
 MODULEDECCXXFLAGS := -msg_quiet 
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 LIBS = -L$(SLB) -lPI -lextsophya -lsophya -lm 
 
Index: /trunk/SophyaPI/PI/Tests/Makefile
===================================================================
--- /trunk/SophyaPI/PI/Tests/Makefile	(revision 2436)
+++ /trunk/SophyaPI/PI/Tests/Makefile	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME := PITest
 MODULEDECCXXFLAGS := -msg_quiet
-include $(DPCDEVREP)/Include/Makefile.h
+include $(SOPHYADEVREP)/Include/Makefile.h
 
 
Index: /trunk/SophyaPI/PIext/cxxexecutor.cc
===================================================================
--- /trunk/SophyaPI/PIext/cxxexecutor.cc	(revision 2436)
+++ /trunk/SophyaPI/PIext/cxxexecutor.cc	(revision 2437)
@@ -648,5 +648,5 @@
 //---------------------------------------------------------------------
 //os<<"MODULEDECCXXFLAGS := -msg_quiet"<<endl;
-//os<<"include $(DPCBASEREP)/Include/MakefileUser.h"<<endl;
+//os<<"include $(SOPHYABASEREP)/Include/MakefileUser.h"<<endl;
 //os<<"MYLIBS ="<<endl;
 //os<<"LIBS = -L$(SLB) -lPI -lextsophya -lsophya -lm"<<endl;
Index: /trunk/SophyaProg/Examples/Makefile
===================================================================
--- /trunk/SophyaProg/Examples/Makefile	(revision 2436)
+++ /trunk/SophyaProg/Examples/Makefile	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME := Tests
 MODULEDECCXXFLAGS := -msg_quiet
-include $(DPCDEVREP)/Include/Makefile.h
+include $(SOPHYADEVREP)/Include/Makefile.h
 
 
Index: /trunk/SophyaProg/Examples/README
===================================================================
--- /trunk/SophyaProg/Examples/README	(revision 2436)
+++ /trunk/SophyaProg/Examples/README	(revision 2437)
@@ -1,6 +1,6 @@
 #   Programmes exemple pour l'utilisation de Sophya
 
-On suppose que $DPCBASREP/`uname`-$EROSCXX/Exec est ds le path et 
-  .:$DPCBASREP/`uname`-$EROSCXX/ShLibs ds LD_LIBRARY_PATH 
+On suppose que $DPCBASREP/`uname`-$SOPHYACXX/Exec est ds le path et 
+  .:$DPCBASREP/`uname`-$SOPHYACXX/ShLibs ds LD_LIBRARY_PATH 
 
 1) ex1.cc 
Index: /trunk/SophyaProg/Examples/auto_makefile
===================================================================
--- /trunk/SophyaProg/Examples/auto_makefile	(revision 2436)
+++ /trunk/SophyaProg/Examples/auto_makefile	(revision 2437)
@@ -14,5 +14,5 @@
 # USERFLAGS := -I/.../myincludes 
 
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 
Index: /trunk/SophyaProg/Examples/ex_makefile
===================================================================
--- /trunk/SophyaProg/Examples/ex_makefile	(revision 2436)
+++ /trunk/SophyaProg/Examples/ex_makefile	(revision 2437)
@@ -16,5 +16,5 @@
 # USERFLAGS := -I/.../myincludes 
 
-include $(DPCBASEREP)/Include/MakefileUser.h
+include $(SOPHYABASEREP)/Include/MakefileUser.h
 
 
Index: /trunk/SophyaProg/PMixer/makeprog
===================================================================
--- /trunk/SophyaProg/PMixer/makeprog	(revision 2436)
+++ /trunk/SophyaProg/PMixer/makeprog	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME := SkyT
 # MODULEDECCXXFLAGS := -msg_quiet
-include $(DPCDEVREP)/Include/Makefile.h
+include $(SOPHYADEVREP)/Include/Makefile.h
 
 ifdef NOSHLIB
Index: /trunk/SophyaProg/Tests/JTCMakefile
===================================================================
--- /trunk/SophyaProg/Tests/JTCMakefile	(revision 2436)
+++ /trunk/SophyaProg/Tests/JTCMakefile	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME := Tests
 MODULEDECCXXFLAGS := -msg_quiet -pthread 
-include $(DPCDEVREP)/Include/Makefile.h
+include $(SOPHYADEVREP)/Include/Makefile.h
 
 # Makefile pour linket avec libJThreadsC++
Index: /trunk/SophyaProg/Tests/Makefile
===================================================================
--- /trunk/SophyaProg/Tests/Makefile	(revision 2436)
+++ /trunk/SophyaProg/Tests/Makefile	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME := Tests
 MODULEDECCXXFLAGS := -msg_quiet
-include $(DPCDEVREP)/Include/Makefile.h
+include $(SOPHYADEVREP)/Include/Makefile.h
 
 
Index: /trunk/SophyaProg/Tests/makepi
===================================================================
--- /trunk/SophyaProg/Tests/makepi	(revision 2436)
+++ /trunk/SophyaProg/Tests/makepi	(revision 2437)
@@ -1,5 +1,5 @@
 MODULECXXREPNAME := Tests
 MODULEDECCXXFLAGS := -msg_quiet
-include $(DPCDEVREP)/Include/Makefile.h
+include $(SOPHYADEVREP)/Include/Makefile.h
 
 

Index: /trunk/SophyaLib/Mgr/Makefile.h
===================================================================
--- /trunk/SophyaLib/Mgr/Makefile.h	(revision 2436)
+++ /trunk/SophyaLib/Mgr/Makefile.h	(revision 2437)
@@ -9,5 +9,5 @@
 # 
 # Makefile variables set are:
 # - Path to Exec, Include, Libs, Obj directories (from DPCDEVREP env. var.)
 #     i.e. variables LIB, OBJ, EXE, INC 
 #---------------------------------------------------------------------------
@@ -22,6 +22,6 @@
 
 #### C++
-ifdef EROSCXX
-  CXX := $(EROSCXX)
+ifdef SOPHYACXX
+  CXX := $(SOPHYACXX)
 endif
 
@@ -30,5 +30,5 @@
 endif
 
-ifeq ($(EROSCXX),egcs++)
+ifeq ($(SOPHYACXX),egcs++)
   # en fait de compilo de egcs++ s'appelle g++ !
   # comme il faut bien differentier ln -s /usr/bin/g++ /usr/bin/egcs++
@@ -49,5 +49,5 @@
 endif
 
-ifeq ($(EROSCXX), egcs++)
+ifeq ($(SOPHYACXX), egcs++)
   CC := egcs
 endif
@@ -77,10 +77,10 @@
 #-  (NE PAS TOUCHER CES LIGNES: generation automatique de MakefileUser.h)
 #-  
-PP  := ${DPCDEVREP}/${MACHDIR}/
+PP  := ${SOPHYADEVREP}/${MACHDIR}/
 LIB := ${PP}/Libs/
 SLB := ${PP}/ShLibs/
 OBJ := ${PP}/Objs/
 EXE := ${PP}/Exec/
-INC := ${DPCDEVREP}/Include/
+INC := ${SOPHYADEVREP}/Include/
 GLB := /usr/local/lib/
 #--
@@ -141,5 +141,5 @@
 ARFLAGS := -static -o
 ARARGS := ^
-EROSCXX := g++
+SOPHYACXX := g++
 CXX := g++
 CC := cc
@@ -9,5 +9,5 @@
 # 
 # Makefile variables set are:
-# - Path to Exec, Include, Libs, Obj directories (from DPCDEVREP env. var.)
+# - Path to Exec, Include, Libs, Obj directories (from SOPHYADEVREP env. var.)
 #     i.e. variables LIB, OBJ, EXE, INC 
 #---------------------------------------------------------------------------